@@ -64,29 +64,35 @@ struct d_name *names_from_str(char* str)
 	return names;
 }
 
-char *_names_to_str_c(char* buffer, struct names *names, char c)
+char *_names_to_str_c(char* buffer, int buffer_size, struct names *names, char c)
 {
-	int n = 0;
 	struct d_name *name;
+	char *b = buffer;
 
 	if (STAILQ_EMPTY(names)) {
-		snprintf(buffer, NAMES_STR_SIZE, "UNKNOWN");
+		snprintf(b, buffer_size, "UNKNOWN");
 		return buffer;
 	}
 
 	name = STAILQ_FIRST(names);
-	while (1) {
-		n += snprintf(buffer + n, NAMES_STR_SIZE - n, "%s", name->name);
+	while (buffer_size > 0) {
+		int n;
+
+		n = snprintf(b, buffer_size, "%s", name->name);
+		if (n < 0 || n >= buffer_size)
+			break;
+		b += n;
+		buffer_size -= n;
 		name = STAILQ_NEXT(name, link);
 		if (!name)
-			return buffer;
-		n += snprintf(buffer + n, NAMES_STR_SIZE - n, "%c", c);
+			break;
+		n = snprintf(b, buffer_size, "%c", c);
+		if (n < 0)
+			break;
+		b += n;
+		buffer_size -= n;
 	}
-}
-
-char *_names_to_str(char* buffer, struct names *names)
-{
-	return _names_to_str_c(buffer, names, ' ');
+	return buffer;
 }
 
 /*
@@ -487,7 +493,7 @@ static void pe_valid_enums(const char **map, int nr_enums)
 	err("Allowed values are: %s\n", buffer);
 }
 
-static void pe_field(struct field_def *field, enum check_codes e, char *value)
+static void pe_field(const struct field_def *field, enum check_codes e, char *value)
 {
 	static const char *err_strings[] = {
 		[CC_NOT_AN_ENUM] = "not valid",
@@ -516,7 +522,7 @@ static void pe_field(struct field_def *field, enum check_codes e, char *value)
 
 static void pe_options(struct context_def *options_def)
 {
-	struct field_def *field;
+	const struct field_def *field;
 	char *buffer, *p;
 	int size = 0;
 
@@ -533,10 +539,10 @@ static void pe_options(struct context_def *options_def)
 	pe_expected(buffer);
 }
 
-static struct field_def *find_field(bool *no_prefix, struct context_def *options_def,
-				    const char *name)
+const struct field_def *find_field(bool *no_prefix, const struct context_def *options_def,
+			     const char *name)
 {
-	struct field_def *field;
+	const struct field_def *field;
 	bool ignored_no_prefix;
 
 	if (no_prefix == NULL)
@@ -549,6 +555,9 @@ static struct field_def *find_field(bool *no_prefix, struct context_def *options
 		*no_prefix = false;
 	}
 
+	if (!options_def)
+		return NULL;
+
 	for (field = options_def->fields; field->name; field++) {
 		if (!strcmp(field->name, name))
 			return field;
@@ -557,7 +566,7 @@ static struct field_def *find_field(bool *no_prefix, struct context_def *options
 	return NULL;
 }
 
-static char *parse_option_value(struct field_def *field_def, bool no_prefix)
+static char *parse_option_value(const struct field_def *field_def, bool no_prefix)
 {
 	char *value;
 	int token;
@@ -583,7 +592,7 @@ static char *parse_option_value(struct field_def *field_def, bool no_prefix)
 /* The syncer section is deprecated. Distribute the options to the disk or net options. */
 void parse_options_syncer(struct d_resource *res)
 {
-	struct field_def *field_def;
+	const struct field_def *field_def;
 	bool no_prefix;
 	char *text, *value;
 	int token;
@@ -627,7 +636,7 @@ static struct options __parse_options(struct context_def *options_def,
 				      void *delegate_context)
 {
 	struct options options = STAILQ_HEAD_INITIALIZER(options);
-	struct field_def *field_def;
+	const struct field_def *field_def;
 	char *value;
 	bool no_prefix;
 	int token;
@@ -663,7 +672,7 @@ static struct options parse_options(struct context_def *options_def)
 static void insert_pd_options_delegate(void *ctx)
 {
 	struct options *options = ctx;
-	struct field_def *field_def;
+	const struct field_def *field_def;
 	bool no_prefix;
 	char *value;
 
@@ -1660,7 +1669,7 @@ void parse_connection_mesh(struct d_resource *res, enum pr_flags flags)
 
 struct d_resource* parse_resource(char* res_name, enum pr_flags flags)
 {
-	struct field_def *proto_f;
+	const struct field_def *proto_f;
 	char *proto_v;
 	struct d_resource* res;
 	struct names host_names;
